@@ -1,18 +1,22 @@
 package Statocles::Types;
 # ABSTRACT: Type constraints and coercions for Statocles
-$Statocles::Types::VERSION = '0.029';
+$Statocles::Types::VERSION = '0.030';
 use Type::Library -base, -declare => qw( Store Theme );
 use Type::Utils -all;
 use Types::Standard -types;
 
-class_type Store, { class => "Statocles::Store" };
-coerce Store, from Str, via { Statocles::Store->new( path => $_ ) };
-coerce Store, from InstanceOf['Path::Tiny'], via { Statocles::Store->new( path => $_ ) };
+role_type Store, { role => "Statocles::Store" };
+coerce Store, from Str, via { Statocles::Store::File->new( path => $_ ) };
+coerce Store, from InstanceOf['Path::Tiny'], via { Statocles::Store::File->new( path => $_ ) };
 
 class_type Theme, { class => "Statocles::Theme" };
 coerce Theme, from Str, via { Statocles::Theme->new( store => $_ ) };
 coerce Theme, from InstanceOf['Path::Tiny'], via { Statocles::Theme->new( store => $_ ) };
 
+# Down here to resolve circular dependencies
+require Statocles::Store::File;
+require Statocles::Theme;
+
 1;
 
 __END__
@@ -25,7 +29,7 @@ Statocles::Types - Type constraints and coercions for Statocles
 
 =head1 VERSION
 
-version 0.029
+version 0.030
 
 =head1 SYNOPSIS
 
@@ -50,11 +54,12 @@ This is a L<type library|Type::Tiny::Manual::Library> for common Statocles types
 
 =head2 Store
 
-A L<Statocles::Store> object.
+An object that consumes the L<Statocles::Store> role.
 
 This can be coerced from any L<Path::Tiny> object or any String, which will be
 used as the filesystem path to the store's documents (the L<path
-attribute|Statocles::Store/path>)
+attribute|Statocles::Store::File/path>). The coersion creates a
+L<Staticles::Store::File> object.
 
 =head2 Theme
 
